# Groundwork

An integrated Django and Javascript framework for people who build tools for organisers.

For more information, check out [the documentation site](https://groundwork.commonknowledge.coop/).

Work on this project kindly supported by [Rosa-Luxemburg-Stiftung](https://www.rosalux.de).
